powered by
Extract Stan State
extract_stan_state(object, phase)
An object of class cmdstanr
cmdstanr
Character string indicating the current phase. Options include wormup and sample/
wormup
sample
A list containing the inverse metric, step size, and last MCMC draw (to be used as the initial value for the next checkpoint)
# NOT RUN { library(cmdstanr) # eight schools example fit_schools_ncp_mcmc <- cmdstanr_example("schools_ncp") extract_stan_state(fit_schools_ncp_mcmc, "sample") # }
Run the code above in your browser using DataLab